--- title: Urubu layout: home content: - start - manual - ref: urubu-quickstart title: Quickstart - faq - more tagline: A micro CMS for static websites ---

#### For websites, not just blogs

Set up a website as logically related content. Content ordering is flexible, not just by date.

#### Focus on navigation

Easily set up a navbar, a table of contents sidebar, breadcrumbs and pagers.

#### Ready for Bootstrap

Urubu plays well with Bootstrap, the popular framework for great looking websites.

#### Markdown content

Enter content in light-weight Markdown syntax, with popular extensions.

#### Wiki links

Easily refer to other pages like in wikis, using Markdown syntax.

#### Powerful templating

Use the powerful Jinja2 templating library to define page layouts.

#### Sophisticated control

Per-page control of page layout and other stuff. Plus user-defined variables.

#### Python power

Urubu is built with Python. It provides Python hooks to assist in templating.

#### Ideal with git

Use a git workflow to develop your website. Deploy by pushing.

And of course, it's open source!